#
# spec file for package librespeed-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sname speedtest-cli
Name:           librespeed-cli
Version:        1.0.11
Release:        2.2
Summary:        Command line client for LibreSpeed
License:        LGPL-3.0-only
URL:            https://github.com/librespeed/speedtest-cli
Source:         %{sname}-%{version}.tar.zst
Source1:        vendor.tar.gz
BuildRequires:  zstd
BuildRequires:  golang(API) >= 1.18

%description
Command line interface for LibreSpeed speed test backends, written in Go.

%prep
%autosetup -a1 -n %{sname}-%{version}

%build
DEFS_PATH="github.com/librespeed/speedtest-cli"
test -n "$SOURCE_DATE_EPOCH" || SOURCE_DATE_EPOCH=$(date +%%s)
go build -mod=vendor -buildmode=pie -ldflags "-w -s \
  -X \"${DEFS_PATH}/defs.ProgName=%{name}\" \
  -X \"${DEFS_PATH}/defs.ProgVersion=%{version}\" \
  -X \"${DEFS_PATH}/defs.BuildDate=$(date -u -d "@$SOURCE_DATE_EPOCH" '+%%Y-%%m-%%d %%H:%%M:%%S %%Z')\" \
" -trimpath

%install
install -Dm755 %{sname} %{buildroot}%{_bindir}/%{name}

%files
%{_bindir}/%{name}
%doc README.md
%license LICENSE

%changelog
* Sun Dec 29 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Allow to override build date (boo#1047218)
* Thu Sep 26 2024 jan.kuzilek@suse.com
- Update to hotfix commit 7573b65ebc89a4cf463334dbdfab5b3edc706149:
  * Upgrade to Go 1.18 as minimum required version
- Update to version 1.0.11:
  * fix build for non-windows/linux platforms
  * go mod tidy to fix build
  * Update goreleaser config to v2
  * add `--ca-cert` option (#81)
  * Fix integer overflow issues at high speeds (#73)
  * Fix code-highlighting (#68)
  * Add interface option (#65)
  * Reduced container image size (#64)
  * Updated dependencies (#62)
  * make `--version` to report the binary version again (#58)
* Thu Jul 18 2024 Jan Kužílek <jan.kuzilek@suse.com>
- Initial package, version 1.0.10
